<?php if (!defined('PmWiki')) exit();
/*

 PmWiki Netflix Queue Plugin

 * Copyright *
 Copyright 2004, by James McDuffie (ttq3sxl02@sneakemail.com)

 * License *
 Same as PmWiki (GNU GPL) 

 * Description *

 This PmWiki module allows you to place markup code in a page that will
 allow inclusion of an individual's Netflix queue or out list. This 
 module allows multiple user to have their Netflix queue displayed on
 the same site. Netflix cookie information is stored in configuration
 files so that others can not know it.

 * Installation Instructions *

 1. Unpack the distribution file where ever you like
 2. Login into your Netflix account and then look in through your browser
    cookies for the NetflixShopperId cookie. The value of this cookie will
    be used to access your Netflix queue.
 2. In your config.php before you include the script code add an entry
    to the NetflixIdList array for an individual. The array is set in the
    following way:

    $NetflixIdList['id_name'] = 'cookie';

    So for the user "bruno" you would add the following where the value
    set is the same string from your browser's cookies list:

    $NetflixIdList['bruno'] = 'PXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX';

 3. Possibly set a new value for the variable $NetflixCacheDir in case
    the default listed in the module does not exist.

 4. Include something like the following in your config.php:

    require_once("local/netflix.php");

 5. Go to the PmWiki page where you want to include netflix information and
    enter the markup to include the Netflix information. For the user "bruno"
    who was set up above you would put the following in the page to include
    both the out list and queue:
   
    [[netflix-out id=bruno]]
    [[netflix-queue id=bruno]]

 6. Edit configurations variables and page markup to your pleasing.

 * History *

 0.1 - Initial version

 * Configuration *

 $NetflixCacheDir - Directory where netflix page is downloaded and cached.
    If it does not exist then then your Queue is downloaded on each access.

 HTML Formatting Variables:

 $NetflixBeginFmt - This string is output before any items are output.
 $NetflixEndFmt   - This string is output after all items are output.

 $NetflixItemFmt  - This string controls how each item in a queue or out
    list are displayed. There are several pseudo-variables that can be
    placed within this string to indicate where information should be
    substituted. The recognized variables are:
      $link             - URL to the current movie
      $movie_id         - Netflix ID of the movie, can be used to get images
      $title            - Name of the movie
      $rating           - MPAA Rating
      $genre            - Genre
      $user_stars       - The star rating of the user
      $predicted_stars  - The star rating from all Netflix users combined

*/

define(NETFLIX_VERSION, '0.1'); 

require("netflix/NetFlixParse.php");

$InlineReplacements['/\[\[netflix-queue id\=(\w*)\]\]/e'] = 
  'NetflixContents("$1", "queue");';

$InlineReplacements['/\[\[netflix-out id\=(\w*)\]\]/e'] = 
  'NetflixContents("$1", "out");';

SDV($NetflixCacheDir, '/tmp/netflix_cache');

SDV($NetflixBeginFmt, '<table>');
SDV($NetflixItemFmt,  '<tr><td><img src="http://a408.g.akamai.net/f/408/1284/24h/image.netflix.com/NetFlix_Assets/boxshots/small/$movie_id.jpg" width="65" height="90" /></td><td><a href="$link">$title</a><br>Genre: $genre<br>Rating: $predicted_stars / 5.0</td></tr>');
SDV($NetflixEndFmt,   '</table>');

function NetflixContents($id_name, $which_list) {
  global $NetflixIdList, $NetflixCacheDir;
  global $NetflixBeginFmt, $NetflixItemFmt, $NetflixEndFmt;

  if(!isset($id_name) || $id_name == '') {
    return "Empty Netflix Id Name";
  }

  $netflix_id = $NetflixIdList[$id_name];

  if(!isset($netflix_id) || $netflix_id == '') {
    return "Id '$id_name' not found in $NetflixIdList";
  }

  $nf_parse = new NetFlixParse($netflix_id, $NetflixCacheDir);
  $nf_parse->parse_data($which_list);
  $items = $nf_parse->get_items();

  $limit = count($items);

  $output_str = $NetflixBeginFmt;

  for($i = 1; $i <= $limit; $i++) {
    $curr_item = $items[$i];

    $output_str .= 
      preg_replace('/\\$(\w*)\\b/e','$curr_item[\'$1\']', $NetflixItemFmt);
  }

  $output_str .= $NetflixEndFmt;

  return $output_str;
}

?>